pub struct CompressedEventLog {
pub log: EventLog,
}Fields
log: EventLogTrait Implementations
Sourceimpl Exportable for CompressedEventLog
impl Exportable for CompressedEventLog
Sourceimpl From<CompressedEventLog> for DeterministicFiniteAutomaton
impl From<CompressedEventLog> for DeterministicFiniteAutomaton
Sourcefn from(value: CompressedEventLog) -> Self
fn from(value: CompressedEventLog) -> Self
Converts to this type from the input type.
Sourceimpl From<CompressedEventLog> for EventLog
impl From<CompressedEventLog> for EventLog
Sourcefn from(value: CompressedEventLog) -> Self
fn from(value: CompressedEventLog) -> Self
Converts to this type from the input type.
Sourceimpl From<CompressedEventLog> for FiniteLanguage
impl From<CompressedEventLog> for FiniteLanguage
Sourcefn from(value: CompressedEventLog) -> Self
fn from(value: CompressedEventLog) -> Self
Converts to this type from the input type.
Sourceimpl From<CompressedEventLog> for FiniteStochasticLanguage
impl From<CompressedEventLog> for FiniteStochasticLanguage
Sourcefn from(value: CompressedEventLog) -> Self
fn from(value: CompressedEventLog) -> Self
Converts to this type from the input type.
Sourceimpl From<CompressedEventLog> for StochasticDeterministicFiniteAutomaton
impl From<CompressedEventLog> for StochasticDeterministicFiniteAutomaton
Sourcefn from(value: CompressedEventLog) -> Self
fn from(value: CompressedEventLog) -> Self
Converts to this type from the input type.
Sourceimpl From<CompressedEventLog> for StochasticNondeterministicFiniteAutomaton
impl From<CompressedEventLog> for StochasticNondeterministicFiniteAutomaton
Sourcefn from(value: CompressedEventLog) -> Self
fn from(value: CompressedEventLog) -> Self
Converts to this type from the input type.
Sourceimpl From<CompressedEventLogTraceAttributes> for CompressedEventLog
impl From<CompressedEventLogTraceAttributes> for CompressedEventLog
Sourcefn from(value: CompressedEventLogTraceAttributes) -> Self
fn from(value: CompressedEventLogTraceAttributes) -> Self
Converts to this type from the input type.
Sourceimpl From<CompressedEventLogXes> for CompressedEventLog
impl From<CompressedEventLogXes> for CompressedEventLog
Sourcefn from(value: CompressedEventLogXes) -> Self
fn from(value: CompressedEventLogXes) -> Self
Converts to this type from the input type.
Sourceimpl From<EventLog> for CompressedEventLog
impl From<EventLog> for CompressedEventLog
Sourceimpl From<EventLogTraceAttributes> for CompressedEventLog
impl From<EventLogTraceAttributes> for CompressedEventLog
Sourcefn from(value: EventLogTraceAttributes) -> Self
fn from(value: EventLogTraceAttributes) -> Self
Converts to this type from the input type.
Sourceimpl From<EventLogXes> for CompressedEventLog
impl From<EventLogXes> for CompressedEventLog
Sourcefn from(value: EventLogXes) -> Self
fn from(value: EventLogXes) -> Self
Converts to this type from the input type.
Sourceimpl FromStr for CompressedEventLog
impl FromStr for CompressedEventLog
Sourceimpl HasActivityKey for CompressedEventLog
impl HasActivityKey for CompressedEventLog
fn activity_key(&self) -> &ActivityKey
fn activity_key_mut(&mut self) -> &mut ActivityKey
Sourceimpl Importable for CompressedEventLog
impl Importable for CompressedEventLog
Sourceconst FILE_FORMAT_SPECIFICATION_LATEX: &str = CompressedEventLogXes::FILE_FORMAT_SPECIFICATION_LATEX
const FILE_FORMAT_SPECIFICATION_LATEX: &str = CompressedEventLogXes::FILE_FORMAT_SPECIFICATION_LATEX
A latex piece that describes the file format.
Sourceconst IMPORTER_PARAMETERS: &[ImporterParameter] = EventLogXes::IMPORTER_PARAMETERS
const IMPORTER_PARAMETERS: &[ImporterParameter] = EventLogXes::IMPORTER_PARAMETERS
Defines the parameters that the importer expects.
fn import_as_object( reader: &mut dyn BufRead, parameter_values: &ImporterParameterValues, ) -> Result<EbiObject>
Sourcefn import(
reader: &mut dyn BufRead,
parameter_values: &ImporterParameterValues,
) -> Result<Self>where
Self: Sized,
fn import(
reader: &mut dyn BufRead,
parameter_values: &ImporterParameterValues,
) -> Result<Self>where
Self: Sized,
Attempts to import from the reader.
The parameter_values must match the order given in
IMPORTER_PARAMETERS.fn default_importer_parameter_values() -> ImporterParameterValues
Sourceimpl TranslateActivityKey for CompressedEventLog
impl TranslateActivityKey for CompressedEventLog
Sourcefn translate_using_activity_key(&mut self, to_activity_key: &mut ActivityKey)
fn translate_using_activity_key(&mut self, to_activity_key: &mut ActivityKey)
Change the activity key of this object, by translating all mentions of activities to the new activity key (which will be updated with activity labels it did not have yet.).
This is a potentially expensive operation. If only a part of the activities will be used, then consider using an ActivityKeyTranslator directly.
The activity key of this object will be updated too, so the activity keys will be equivalent afterwards.
Sourceimpl TryFrom<CompressedEventLog> for EventLogCsv
impl TryFrom<CompressedEventLog> for EventLogCsv
Sourceimpl TryFrom<EventLogCsv> for CompressedEventLog
impl TryFrom<EventLogCsv> for CompressedEventLog