pub struct EventLogPython {
pub log: EventLogXes,
}Expand description
A Python log is an XES log, but without trace attributes. There are no importers, as Python logs can only come from Python.
Fields
log: EventLogXesTrait Implementations
Sourceimpl Clone for EventLogPython
impl Clone for EventLogPython
Sourcefn clone(&self) -> EventLogPython
fn clone(&self) -> EventLogPython
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Display for EventLogPython
impl Display for EventLogPython
Sourceimpl Exportable for EventLogPython
impl Exportable for EventLogPython
Sourceimpl From<(EventLog, EventLogClassifier)> for EventLogPython
impl From<(EventLog, EventLogClassifier)> for EventLogPython
Sourcefn from(value: (EventLog, EventLogClassifier)) -> Self
fn from(value: (EventLog, EventLogClassifier)) -> Self
Converts to this type from the input type.
Sourceimpl From<EventLogPython> for DeterministicFiniteAutomaton
impl From<EventLogPython> for DeterministicFiniteAutomaton
Sourcefn from(value: EventLogPython) -> Self
fn from(value: EventLogPython) -> Self
Converts to this type from the input type.
Sourceimpl From<EventLogPython> for EventLog
impl From<EventLogPython> for EventLog
Sourcefn from(value: EventLogPython) -> Self
fn from(value: EventLogPython) -> Self
Converts to this type from the input type.
Sourceimpl From<EventLogPython> for EventLogXes
impl From<EventLogPython> for EventLogXes
Sourcefn from(value: EventLogPython) -> Self
fn from(value: EventLogPython) -> Self
Converts to this type from the input type.
Sourceimpl From<EventLogPython> for FiniteLanguage
impl From<EventLogPython> for FiniteLanguage
Sourcefn from(value: EventLogPython) -> Self
fn from(value: EventLogPython) -> Self
Converts to this type from the input type.
Sourceimpl From<EventLogPython> for FiniteStochasticLanguage
impl From<EventLogPython> for FiniteStochasticLanguage
Sourcefn from(value: EventLogPython) -> Self
fn from(value: EventLogPython) -> Self
Converts to this type from the input type.
Sourceimpl From<EventLogPython> for StochasticDeterministicFiniteAutomaton
impl From<EventLogPython> for StochasticDeterministicFiniteAutomaton
Sourcefn from(value: EventLogPython) -> Self
fn from(value: EventLogPython) -> Self
Converts to this type from the input type.
Sourceimpl From<EventLogPython> for StochasticNondeterministicFiniteAutomaton
impl From<EventLogPython> for StochasticNondeterministicFiniteAutomaton
Sourcefn from(value: EventLogPython) -> Self
fn from(value: EventLogPython) -> Self
Converts to this type from the input type.
Sourceimpl From<EventLogXes> for EventLogPython
impl From<EventLogXes> for EventLogPython
Sourcefn from(value: EventLogXes) -> Self
fn from(value: EventLogXes) -> Self
Converts to this type from the input type.
Sourceimpl HasActivityKey for EventLogPython
impl HasActivityKey for EventLogPython
fn activity_key(&self) -> &ActivityKey
fn activity_key_mut(&mut self) -> &mut ActivityKey
Sourceimpl Importable for EventLogPython
impl Importable for EventLogPython
Sourceconst IMPORTER_PARAMETERS: &[ImporterParameter]
const IMPORTER_PARAMETERS: &[ImporterParameter]
Defines the parameters that the importer expects.
Sourceconst FILE_FORMAT_SPECIFICATION_LATEX: &str = "A Pm4py log can be imported by Ebi from Python. Ensure to set \\texttt{return\\_legacy\\_log\\_object=True} at importing."
const FILE_FORMAT_SPECIFICATION_LATEX: &str = "A Pm4py log can be imported by Ebi from Python. Ensure to set \\texttt{return\\_legacy\\_log\\_object=True} at importing."
A latex piece that describes the file format.
fn import_as_object( _reader: &mut dyn BufRead, _parameter_values: &ImporterParameterValues, ) -> Result<EbiObject>
Sourcefn import(
_reader: &mut dyn BufRead,
_parameter_values: &ImporterParameterValues,
) -> Result<Self>where
Self: Sized,
fn import(
_reader: &mut dyn BufRead,
_parameter_values: &ImporterParameterValues,
) -> Result<Self>where
Self: Sized,
Attempts to import from the reader.
The parameter_values must match the order given in
IMPORTER_PARAMETERS.fn default_importer_parameter_values() -> ImporterParameterValues
Sourceimpl NumberOfTraces for EventLogPython
impl NumberOfTraces for EventLogPython
fn number_of_traces(&self) -> usize
fn number_of_events(&self) -> usize
Sourceimpl TranslateActivityKey for EventLogPython
impl TranslateActivityKey for EventLogPython
Sourcefn translate_using_activity_key(&mut self, to_activity_key: &mut ActivityKey)
fn translate_using_activity_key(&mut self, to_activity_key: &mut ActivityKey)
Change the activity key of this object, by translating all mentions of activities to the new activity key (which will be updated with activity labels it did not have yet.).
This is a potentially expensive operation. If only a part of the activities will be used, then consider using an ActivityKeyTranslator directly.
The activity key of this object will be updated too, so the activity keys will be equivalent afterwards.