pub struct ProcessTreeMarkupLanguage {
pub tree: ProcessTree,
}Fields
tree: ProcessTreeTrait Implementations
Sourceimpl Clone for ProcessTreeMarkupLanguage
impl Clone for ProcessTreeMarkupLanguage
Sourcefn clone(&self) -> ProcessTreeMarkupLanguage
fn clone(&self) -> ProcessTreeMarkupLanguage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl From<ProcessTreeMarkupLanguage> for BusinessProcessModelAndNotation
impl From<ProcessTreeMarkupLanguage> for BusinessProcessModelAndNotation
Sourcefn from(value: ProcessTreeMarkupLanguage) -> Self
fn from(value: ProcessTreeMarkupLanguage) -> Self
Converts to this type from the input type.
Sourceimpl From<ProcessTreeMarkupLanguage> for DeterministicFiniteAutomaton
impl From<ProcessTreeMarkupLanguage> for DeterministicFiniteAutomaton
Sourcefn from(value: ProcessTreeMarkupLanguage) -> Self
fn from(value: ProcessTreeMarkupLanguage) -> Self
Converts to this type from the input type.
Sourceimpl From<ProcessTreeMarkupLanguage> for LabelledPetriNet
impl From<ProcessTreeMarkupLanguage> for LabelledPetriNet
Sourcefn from(value: ProcessTreeMarkupLanguage) -> Self
fn from(value: ProcessTreeMarkupLanguage) -> Self
Converts to this type from the input type.
Sourceimpl From<ProcessTreeMarkupLanguage> for ProcessTree
impl From<ProcessTreeMarkupLanguage> for ProcessTree
Sourcefn from(value: ProcessTreeMarkupLanguage) -> Self
fn from(value: ProcessTreeMarkupLanguage) -> Self
Converts to this type from the input type.
Sourceimpl FromStr for ProcessTreeMarkupLanguage
impl FromStr for ProcessTreeMarkupLanguage
Sourceimpl Graphable for ProcessTreeMarkupLanguage
impl Graphable for ProcessTreeMarkupLanguage
fn to_dot(&self) -> Result<VisualGraph>
Sourceimpl HasActivityKey for ProcessTreeMarkupLanguage
impl HasActivityKey for ProcessTreeMarkupLanguage
fn activity_key(&self) -> &ActivityKey
fn activity_key_mut(&mut self) -> &mut ActivityKey
Sourceimpl Importable for ProcessTreeMarkupLanguage
impl Importable for ProcessTreeMarkupLanguage
Sourceconst FILE_FORMAT_SPECIFICATION_LATEX: &str = "A process tree markup language file.
For instance:
\\lstinputlisting[language=xml, style=boxed]{../testfiles/aa-ab-ba.ptml}"
const FILE_FORMAT_SPECIFICATION_LATEX: &str = "A process tree markup language file. For instance: \\lstinputlisting[language=xml, style=boxed]{../testfiles/aa-ab-ba.ptml}"
A latex piece that describes the file format.
Sourceconst IMPORTER_PARAMETERS: &[ImporterParameter]
const IMPORTER_PARAMETERS: &[ImporterParameter]
Defines the parameters that the importer expects.
fn import_as_object( reader: &mut dyn BufRead, parameter_values: &ImporterParameterValues, ) -> Result<EbiObject>
Sourcefn import(reader: &mut dyn BufRead, _: &ImporterParameterValues) -> Result<Self>where
Self: Sized,
fn import(reader: &mut dyn BufRead, _: &ImporterParameterValues) -> Result<Self>where
Self: Sized,
Attempts to import from the reader.
The parameter_values must match the order given in
IMPORTER_PARAMETERS.fn default_importer_parameter_values() -> ImporterParameterValues
Sourceimpl TranslateActivityKey for ProcessTreeMarkupLanguage
impl TranslateActivityKey for ProcessTreeMarkupLanguage
Sourcefn translate_using_activity_key(&mut self, to_activity_key: &mut ActivityKey)
fn translate_using_activity_key(&mut self, to_activity_key: &mut ActivityKey)
Change the activity key of this object, by translating all mentions of activities to the new activity key (which will be updated with activity labels it did not have yet.).
This is a potentially expensive operation. If only a part of the activities will be used, then consider using an ActivityKeyTranslator directly.
The activity key of this object will be updated too, so the activity keys will be equivalent afterwards.