BusinessProcessModelAndNotation

Struct BusinessProcessModelAndNotation 

pub struct BusinessProcessModelAndNotation {
    pub activity_key: ActivityKey,
    pub collaboration_index: Option<(usize, ())>,
    pub collaboration_id: Option<String>,
    pub definitions_index: (usize, ()),
    pub definitions_id: String,
    pub elements: Vec<BPMNElement>,
    pub message_flows: Vec<BPMNMessageFlow>,
    /* private fields */
}
A struct with a Business Process Model and Notation (BPMN) model.

Example:

use std::io::prelude::*;
use std::io::BufReader;
use std::fs::File;
use ebi_bpmn::BusinessProcessModelAndNotation;

fn main() -> anyhow::Result<()> {
 let f = File::open("testfiles/model.bpmn")?;
 let mut reader = BufReader::new(f);

 let bpmn = BusinessProcessModelAndNotation::import_from_reader(&mut reader, true)?;

 let mut marking = bpmn.get_initial_marking()?.unwrap();
assert_eq!(bpmn.get_enabled_transitions(&marking)?, vec![0]);
 bpmn.execute_transition(&mut marking, 0)?;

Ok(())
}

To create a BPMN model programmatically, please consider using a BPMNCreator.

Fields

activity_key: ActivityKeycollaboration_index: Option<(usize, ())>collaboration_id: Option<String>definitions_index: (usize, ())definitions_id: Stringelements: Vec<BPMNElement>message_flows: Vec<BPMNMessageFlow>

Implementations

Source

impl BusinessProcessModelAndNotation

pub fn number_of_elements(&self) -> usize

Returns the number of elements in the BPMN model (recurses).

pub fn number_of_message_flows(&self) -> usize

Returns the number of message flows in the BPMN model (does not recurse).

pub fn elements(&self) -> Vec<&BPMNElement>

Returns all elements in the model (recurses).

pub fn parent_of(&self, global_index: (usize, ())) -> Option<&dyn Processable>

Returns the parent of the element or flow with the given index (recursively).

pub fn sequence_flows(&self) -> Vec<&BPMNSequenceFlow>

Returns all sequence flows (recurses).

pub fn global_index_2_element(&self, index: (usize, ())) -> Option<&BPMNElement>

Find an element with the given index (recurses).

pub fn global_index_2_element_mut( &mut self, index: (usize, ()), ) -> Option<&mut BPMNElement>

Find an element with the given index and returns a mutable reference to it (recurses).

pub fn message_flow_index_2_source( &self, message_flow_index: usize, ) -> Result<&BPMNElement, Error>

Returns the element that is the source of the given message flow.

pub fn message_flow_index_2_target( &self, message_flow_index: usize, ) -> Result<&BPMNElement, Error>

Returns the element that is the target of the given message flow.

pub fn global_index_2_message_flow( &self, message_flow_global_index: (usize, ()), ) -> Option<&BPMNMessageFlow>

Returns the sequence flow with the given global index.

pub fn global_index_2_sequence_flow_and_parent( &self, sequence_flow_global_index: (usize, ()), ) -> Option<(&BPMNSequenceFlow, &dyn Processable)>

Returns the sequence flow with the given global index.

pub fn global_index_2_sequence_flow_mut( &mut self, sequence_flow_global_index: (usize, ()), ) -> Option<&mut BPMNSequenceFlow>

Returns the sequence flow with this index, if it exists (recurses).

Source

impl BusinessProcessModelAndNotation

pub fn export_to_writer(&self, f: &mut dyn Write) -> Result<(), Error>

Exports the model to a writer.

Source

impl BusinessProcessModelAndNotation

pub fn import_from_reader( reader: &mut dyn BufRead, disallow_sequence_flow_weights: bool, ) -> Result<BusinessProcessModelAndNotation, Error>

Attempts to import a BPMN model. If disallow_sequence_flow_weights is set to true, parsing will fail if any sequence flow has a weight. Will only succeed if the model is structurally correct.

Source

impl BusinessProcessModelAndNotation

pub fn get_initial_marking(&self) -> Result<Option<BPMNMarking>, Error>

Returns the initial marking, as specified by the BPMN 2.0.2 standard on page 238. Additionally, if the model is empty, it does not support any trace, and this function returns Ok(None). If the model is structurally correct, this method will always return Ok(..). If not, will return Err() but will not panic.

pub fn execute_transition( &self, marking: &mut BPMNMarking, transition_index: usize, ) -> Result<(), Error>

Updates the marking by executing the transition. By contract, will return Ok() if the model is structurally correct and the transition was enabled. May panic or return Err() otherwise.

pub fn is_final_marking(&self, marking: &BPMNMarking) -> Result<bool, Error>

Returns whether the marking is a final marking. That is, whether no transitions are enabled in it. If the model is structurally correct, this function will always return Ok(). If the model is not structurally correct, this function may return Err() but will not panic.

pub fn is_transition_silent( &self, transition_index: usize, marking: &BPMNMarking, ) -> bool

Returns true if the transition exists and is unlabelled, otherwise, returns false. Does not panic.

pub fn get_transition_activity( &self, transition_index: usize, marking: &BPMNMarking, ) -> Option<Activity>

If the transition exists and is labelled, returns the label. Otherwise, returns None.

pub fn get_enabled_transitions( &self, marking: &BPMNMarking, ) -> Result<Vec<usize>, Error>

Returns the transitions that are enabled in the given marking. By contract, will return Ok() if the model is structurally correct. Otherwise, it will return Err() but will not panic.

pub fn number_of_transitions(&self, marking: &BPMNMarking) -> usize

Returns the number of transitions of the current marking. Note that not all of these transitions are necessarily enabled.

pub fn transition_debug( &self, transition_index: usize, marking: &BPMNMarking, ) -> Option<String>

Print a list of transitions at the current marking.

pub fn transition_2_consumed_tokens( &self, transition_index: usize, marking: &BPMNMarking, ) -> Result<Vec<Token>, Error>

Returns the tokens that are consumed when this transition is fired, or None if the transition does not exist.

pub fn transition_2_produced_tokens( &self, transition_index: usize, marking: &BPMNMarking, ) -> Result<Vec<Token>, Error>

Returns the tokens that are produced when this transition is fired, or None if the transition does not exist.

Source

impl BusinessProcessModelAndNotation

pub fn is_structurally_correct(&self) -> Result<(), Error>

Verify whether the model is structurally correct using several, though not exhaustive, checks. If the BPMN model is imported by import_from_reader or created using a BPMNCreator, there is no need to call this method.