pub enum ImporterParameter {
Flag {
name: &'static str,
short_name: &'static str,
explanation: &'static str,
},
String {
name: &'static str,
short_name: &'static str,
explanation: &'static str,
allowed_values: Option<&'static [&'static str]>,
default_value: &'static str,
},
Usize {
name: &'static str,
short_name: &'static str,
explanation: &'static str,
minimum_value: Option<usize>,
maximum_value: Option<usize>,
default_value: usize,
},
Fraction {
name: &'static str,
short_name: &'static str,
explanation: &'static str,
minimum_value: Option<ConstFraction>,
maximum_value: Option<ConstFraction>,
default_value: ConstFraction,
},
}Expand description
Parameters that can be given to an importer. It is a design decision that every parameter must have a default, to ensure every importer (also) works without user interaction.
Variants
Flag
String
Fields
Usize
Fields
Fraction
Fields

minimum_value: Option<ConstFraction>
maximum_value: Option<ConstFraction>
default_value: ConstFractionImplementations
Sourceimpl ImporterParameter
impl ImporterParameter
pub fn name(&self) -> &'static str
pub fn short_name(&self) -> &'static str
pub fn explanation(&self) -> &'static str
pub fn default(&self) -> ImporterParameterValue