StochasticProcessTree

Struct StochasticProcessTree 

pub struct StochasticProcessTree {
    pub activity_key: ActivityKey,
    pub tree: Vec<Node>,
    pub transition2node: Vec<usize>,
    pub weights: Vec<Fraction>,
    pub termination_weight: Fraction,
}

Fields

activity_key: ActivityKeytree: Vec<Node>transition2node: Vec<usize>weights: Vec<Fraction>termination_weight: Fraction

Implementations

Source

impl StochasticProcessTree

pub fn node_to_lpn( &self, node: usize, net: &mut LabelledPetriNet, translator: &ActivityKeyTranslator, source: usize, sink: usize, ) -> Result<usize>

Source

impl StochasticProcessTree

pub fn get_number_of_nodes(&self) -> usize

pub fn get_node(&self, node: usize) -> Option<&Node>

pub fn root(&self) -> usize

pub fn get_node_of_transition( &self, transition: TransitionIndex, ) -> Result<&Node>

pub fn get_parent(&self, node: usize) -> Option<(usize, usize)>

Returns the parent of node. Notice that this is an expensive operation; avoid if possible.

@param node @return The parent of node, and the rank of the child

pub fn get_child_rank_with( &self, parent: usize, grand_child: usize, ) -> Option<usize>

@param parent @param grandChild @return The number of the child within parent that contains grandChild. If grandChild is not a child of parent, will return -1.

pub fn get_children(&self, node: usize) -> StochasticChildrenIterator<'_>

pub fn get_parents(&self, node: usize) -> StochasticParentsIterator<'_>

pub fn get_descendants(&self, node: usize) -> &[Node]

pub fn is_parent_of(&self, parent: usize, child: usize) -> bool

@param parent @param child @return Whether the child is a direct or indirect child of parent.

pub fn traverse(&self, node: usize) -> usize

Find the next node of this node: the next sibling, and if that is not available, the next sibling up the tree. May return a non-existing node if there is no sibling.

pub fn get_child(&self, parent: usize, child_rank: usize) -> usize

pub fn get_number_of_children(&self, parent: usize) -> Option<usize>

pub fn node_to_transition(&self, node: usize) -> Option<usize>

pub fn import_as_labelled_petri_net( reader: &mut dyn BufRead, ) -> Result<EbiObject>

Source

impl StochasticProcessTree

pub fn node_to_string( &self, indent: usize, node: usize, f: &mut Formatter<'_>, ) -> Result<usize>

pub fn node_to_dot( &self, graph: &mut VisualGraph, node: usize, entry: &NodeHandle, exit: &NodeHandle, ) -> usize