pub struct BusinessProcessModelAndNotation {
pub activity_key: ActivityKey,
pub collaboration_index: Option<(usize, ())>,
pub collaboration_id: Option<String>,
pub definitions_index: (usize, ()),
pub definitions_id: String,
pub elements: Vec<BPMNElement>,
pub message_flows: Vec<BPMNMessageFlow>,
/* private fields */
}Fields
activity_key: ActivityKeycollaboration_index: Option<(usize, ())>collaboration_id: Option<String>definitions_index: (usize, ())definitions_id: Stringelements: Vec<BPMNElement>message_flows: Vec<BPMNMessageFlow>Implementations
Sourceimpl BusinessProcessModelAndNotation
impl BusinessProcessModelAndNotation
pub fn number_of_elements(&self) -> usize
pub fn number_of_message_flows(&self) -> usize
Sourcepub fn elements(&self) -> Vec<&BPMNElement>
pub fn elements(&self) -> Vec<&BPMNElement>
returns all elements in the model (recursively)
pub fn parent_of(&self, global_index: (usize, ())) -> Option<&dyn Processable>
Sourcepub fn sequence_flows(&self) -> Vec<&BPMNSequenceFlow>
pub fn sequence_flows(&self) -> Vec<&BPMNSequenceFlow>
Returns all sequence flows (recursive)
Sourcepub fn global_index_2_element(&self, index: (usize, ())) -> Option<&BPMNElement>
pub fn global_index_2_element(&self, index: (usize, ())) -> Option<&BPMNElement>
find an element with the given index
Sourcepub fn global_index_2_element_mut(
&mut self,
index: (usize, ()),
) -> Option<&mut BPMNElement>
pub fn global_index_2_element_mut( &mut self, index: (usize, ()), ) -> Option<&mut BPMNElement>
find an element with the given index
Sourcepub fn index_2_object(&self, index: (usize, ())) -> Option<&dyn BPMNObject>
pub fn index_2_object(&self, index: (usize, ())) -> Option<&dyn BPMNObject>
find the object of the given index
Sourcepub fn message_flow_index_2_source(
&self,
message_flow_index: usize,
) -> Result<&BPMNElement, Error>
pub fn message_flow_index_2_source( &self, message_flow_index: usize, ) -> Result<&BPMNElement, Error>
return the element that is the source of the given message flow
Sourcepub fn message_flow_index_2_target(
&self,
message_flow_index: usize,
) -> Result<&BPMNElement, Error>
pub fn message_flow_index_2_target( &self, message_flow_index: usize, ) -> Result<&BPMNElement, Error>
return the element that is the target of the given message flow
Sourcepub fn global_index_2_sequence_flow_and_parent(
&self,
sequence_flow_global_index: (usize, ()),
) -> Option<(&BPMNSequenceFlow, &dyn Processable)>
pub fn global_index_2_sequence_flow_and_parent( &self, sequence_flow_global_index: (usize, ()), ) -> Option<(&BPMNSequenceFlow, &dyn Processable)>
return the sequence flow with the given global index
pub fn transition_debug( &self, transition_index: usize, marking: &BPMNMarking, ) -> Option<String>
Sourcepub fn transition_2_marked_sequence_flows(
&self,
transition_index: usize,
marking: &BPMNMarking,
) -> Option<Vec<(usize, ())>>
pub fn transition_2_marked_sequence_flows( &self, transition_index: usize, marking: &BPMNMarking, ) -> Option<Vec<(usize, ())>>
Returns the global indices of sequence flows that get a token by executing this transition.
Sourcepub fn global_index_2_sequence_flow_mut(
&mut self,
sequence_flow_global_index: (usize, ()),
) -> Option<&mut BPMNSequenceFlow>
pub fn global_index_2_sequence_flow_mut( &mut self, sequence_flow_global_index: (usize, ()), ) -> Option<&mut BPMNSequenceFlow>
return the sequence flow with this index, if it exists (recurses)
Sourceimpl BusinessProcessModelAndNotation
impl BusinessProcessModelAndNotation
Sourcepub fn import_from_reader(
reader: &mut dyn BufRead,
disallow_sequence_flow_weights: bool,
) -> Result<BusinessProcessModelAndNotation, Error>where
BusinessProcessModelAndNotation: Sized,
pub fn import_from_reader(
reader: &mut dyn BufRead,
disallow_sequence_flow_weights: bool,
) -> Result<BusinessProcessModelAndNotation, Error>where
BusinessProcessModelAndNotation: Sized,
Attempts to import a BPMN model. If disallow_sequence_flow_weights is set to true, parsing will fail if any sequence flow has a weight.
Sourceimpl BusinessProcessModelAndNotation
impl BusinessProcessModelAndNotation
Sourcepub fn get_initial_marking(&self) -> Result<BPMNMarking, Error>
pub fn get_initial_marking(&self) -> Result<BPMNMarking, Error>
BPMN 2.0.2 standard page 238
pub fn execute_transition( &self, marking: &mut BPMNMarking, transition_index: usize, ) -> Result<(), Error>
pub fn is_final_marking(&self, marking: &BPMNMarking) -> Result<bool, Error>
pub fn is_transition_silent( &self, transition_index: usize, marking: &BPMNMarking, ) -> bool
pub fn get_transition_activity( &self, transition_index: usize, marking: &BPMNMarking, ) -> Option<Activity>
pub fn get_enabled_transitions( &self, marking: &BPMNMarking, ) -> Result<Vec<usize>, Error>
pub fn number_of_transitions(&self, marking: &BPMNMarking) -> usize
Sourceimpl BusinessProcessModelAndNotation
impl BusinessProcessModelAndNotation
pub fn is_structurally_correct(&self) -> Result<(), Error>