pub trait IntoAttributeIterator {
// Required methods
fn iter_categorical(
&self,
attribute: Attribute,
) -> CategoricalAttributeIterator<'_> ⓘ;
fn iter_numeric(&self, attribute: Attribute) -> NumericAttributeIterator<'_> ⓘ;
fn iter_time(&self, attribute: Attribute) -> TimeAttributeIterator<'_> ⓘ;
}Required Methods
Sourcefn iter_categorical(
&self,
attribute: Attribute,
) -> CategoricalAttributeIterator<'_> ⓘ
fn iter_categorical( &self, attribute: Attribute, ) -> CategoricalAttributeIterator<'_> ⓘ
Iterator over the categorical attribute values of traces, i.e. for traces that do not have the attribute set, a None is included. A call to .flatten() transforms this to remove those values.
Sourcefn iter_numeric(&self, attribute: Attribute) -> NumericAttributeIterator<'_> ⓘ
fn iter_numeric(&self, attribute: Attribute) -> NumericAttributeIterator<'_> ⓘ
Iterator over tbe numeric attribute values of traces, i.e. for traces that do not have the attribute set, a None is included. A call to .flatten() transforms this to remove those values.
Sourcefn iter_time(&self, attribute: Attribute) -> TimeAttributeIterator<'_> ⓘ
fn iter_time(&self, attribute: Attribute) -> TimeAttributeIterator<'_> ⓘ
Iterator over the time attribute values of traces, i.e. for traces that do not have the attribute set, a None is included. A call to .flatten() transforms this to remove those values.